@@ -93,13 +93,6 @@ class TransactionForm(forms.Form):
     """
 
     def __init__(self, transaction: Transaction, *args, **kwargs):
-        # For testing via anchor-validator.herokuapp.com
-        test_value = kwargs.pop("test_value", None)
-        if not test_value:
-            test_value = (
-                "103" if transaction.kind == Transaction.KIND.deposit else "100"
-            )
-
         super().__init__(*args, **kwargs)
 
         self.transaction = transaction
@@ -127,7 +120,6 @@ class TransactionForm(forms.Form):
                     "class": "input",
                     "inputmode": "decimal",
                     "symbol": self.asset.symbol,
-                    "test-value": test_value,
                 }
             ),
             min_value=self.min_amount,
