@@ -1,6 +1,5 @@
 """This module defines the models used by Polaris."""
 import uuid
-import json
 import decimal
 import datetime
 import secrets
@@ -332,7 +331,7 @@ class Transaction(models.Model):
 
     status_to_message = {
         # SEP-6 & SEP-24
-        "pending_anchor": _("Processing"),
+        "pending_anchor": _("processing"),
         "pending_trust": _("waiting for a trustline to be established"),
         "pending_user": _("waiting on user action"),
         "pending_user_transfer_start": _("waiting on the user to transfer funds"),
@@ -367,8 +366,6 @@ class Transaction(models.Model):
     paging_token = models.TextField(null=True)
     """The token to be used as a cursor for querying before or after this transaction"""
 
-    # Stellar account to watch, and asset that is being transacted
-    # NOTE: these fields should not be publicly exposed
     stellar_account = models.TextField(validators=[MinLengthValidator(1)])
     """The stellar source account for the transaction."""
 
@@ -559,7 +556,7 @@ class Transaction(models.Model):
     """True if the transaction was refunded, false otherwise."""
 
     protocol = models.CharField(choices=PROTOCOL, null=True, max_length=5)
-    """Either 'sep6' or 'sep24'"""
+    """Either 'sep6', 'sep24', or 'sep31'"""
 
     pending_signatures = models.BooleanField(default=False)
     """
@@ -573,21 +570,45 @@ class Transaction(models.Model):
     the encoded transaction.
     """
 
-    channel_seed = models.TextField(null=True, blank=True)
+    channel_seed = EncryptedTextField(null=True, blank=True)
     """
     A keypair of the account used when sending SEP-6 or SEP-24 deposit 
     transactions to Transaction.stellar_account, if present. 
     This is only used for transactions requiring signatures Polaris cannot
     add itself.
     """
+
     claimable_balance_supported = models.BooleanField(default=False)
     """
     claimable_balance_supported is a boolean to indicate if the wallet supports the SEP24
     requirements for handeling claimable balance deposits.
     """
+
     claimable_balance_id = models.TextField(null=True, blank=True)
     """
-    The ID of the claimable balance used to send funds to the user. This column will be ``None`` if ``claimable_balance_supported`` is ``False`` or if the transaction has not yet been submitted to the Stellar network.
+    The ID of the claimable balance used to send funds to the user. This column will be
+    ``None`` if ``claimable_balance_supported`` is ``False`` or if the transaction has
+    not yet been submitted to the Stellar network.
+    """
+
+    more_info_url = models.TextField(null=True, blank=True)
+    """
+    A URL that is opened by wallets after the interactive flow is complete. It can include
+    banking information for users to start deposits, the status of the transaction, or any
+    other information the user might need to know about the transaction.
+    """
+
+    on_change_callback = models.TextField(null=True, blank=True)
+    """
+    A URL that the anchor should POST a JSON message to when the status property of the
+    transaction created as a result of this request changes.
+    """
+
+    pending_execution_attempt = models.BooleanField(default=False)
+    """
+    An internal column used to ensure transactions are not retrieved from the database 
+    and executed by different processes running the same command, specifically 
+    poll_pending_deposits, check_trustlines or execute_outgoing_transactions.
     """
 
     objects = models.Manager()
