@@ -9,13 +9,16 @@ import os
 import binascii
 import time
 import jwt
+from urllib.parse import urlparse
 
-from django.utils.translation import gettext as _
+from django.utils.translation import gettext
 from rest_framework import status
 from rest_framework.views import APIView
 from rest_framework.request import Request
 from rest_framework.response import Response
 from rest_framework.parsers import JSONParser, MultiPartParser, FormParser
+from rest_framework.renderers import JSONRenderer, BrowsableAPIRenderer
+from stellar_sdk import ReturnHashMemo, NoneMemo
 from stellar_sdk.sep.stellar_web_authentication import (
     build_challenge_transaction,
     read_challenge_transaction,
@@ -26,8 +29,7 @@ from stellar_sdk.sep.exceptions import InvalidSep10ChallengeError
 from stellar_sdk.exceptions import NotFoundError
 
 from polaris import settings
-from polaris.utils import getLogger
-from polaris.utils import render_error_response
+from polaris.utils import getLogger, render_error_response
 
 MIME_URLENCODE, MIME_JSON = "application/x-www-form-urlencoded", "application/json"
 logger = getLogger(__name__)
@@ -42,6 +44,7 @@ class SEP10Auth(APIView):
     """
 
     parser_classes = [JSONParser, MultiPartParser, FormParser]
+    renderer_classes = [JSONRenderer, BrowsableAPIRenderer]
 
     ###############
     # GET functions
@@ -88,6 +91,7 @@ class SEP10Auth(APIView):
             server_secret=settings.SIGNING_SEED,
             client_account_id=client_account,
             home_domain=home_domain,
+            web_auth_domain=urlparse(settings.HOST_URL).netloc,
             network_passphrase=settings.STELLAR_NETWORK_PASSPHRASE,
             timeout=900,
         )
@@ -98,7 +102,7 @@ class SEP10Auth(APIView):
     def post(self, request: Request, *_args, **_kwargs) -> Response:
         envelope_xdr = request.data.get("transaction")
         if not envelope_xdr:
-            return render_error_response(_("'transaction' is required"))
+            return render_error_response(gettext("'transaction' is required"))
         try:
             self._validate_challenge_xdr(envelope_xdr)
         except ValueError as e:
@@ -126,6 +130,7 @@ class SEP10Auth(APIView):
                 challenge_transaction=envelope_xdr,
                 server_account_id=settings.SIGNING_KEY,
                 home_domains=settings.SEP10_HOME_DOMAINS,
+                web_auth_domain=urlparse(settings.HOST_URL).netloc,
                 network_passphrase=settings.STELLAR_NETWORK_PASSPHRASE,
             )
         except InvalidSep10ChallengeError as e:
@@ -136,14 +141,13 @@ class SEP10Auth(APIView):
         try:
             account = settings.HORIZON_SERVER.load_account(account_id)
         except NotFoundError:
-            logger.warning(
-                "Account does not exist, using client's master key to verify"
-            )
+            logger.info("Account does not exist, using client's master key to verify")
             try:
                 verify_challenge_transaction_signed_by_client_master_key(
                     challenge_transaction=envelope_xdr,
                     server_account_id=settings.SIGNING_KEY,
                     home_domains=settings.SEP10_HOME_DOMAINS,
+                    web_auth_domain=urlparse(settings.HOST_URL).netloc,
                     network_passphrase=settings.STELLAR_NETWORK_PASSPHRASE,
                 )
                 if len(tx_envelope.signatures) != 2:
@@ -167,6 +171,7 @@ class SEP10Auth(APIView):
                 challenge_transaction=envelope_xdr,
                 server_account_id=settings.SIGNING_KEY,
                 home_domains=settings.SEP10_HOME_DOMAINS,
+                web_auth_domain=urlparse(settings.HOST_URL).netloc,
                 network_passphrase=settings.STELLAR_NETWORK_PASSPHRASE,
                 threshold=threshold,
                 signers=signers,
@@ -189,6 +194,7 @@ class SEP10Auth(APIView):
             challenge_transaction=envelope_xdr,
             server_account_id=settings.SIGNING_KEY,
             home_domains=settings.SEP10_HOME_DOMAINS,
+            web_auth_domain=urlparse(settings.HOST_URL).netloc,
             network_passphrase=settings.STELLAR_NETWORK_PASSPHRASE,
         )
         logger.info(
