@@ -4,7 +4,6 @@ This lets a user initiate a deposit of an asset into their Stellar account.
 """
 from decimal import Decimal, DecimalException
 from urllib.parse import urlencode
-from polaris.utils import getLogger
 
 from django.urls import reverse
 from django.core.exceptions import ValidationError
@@ -13,20 +12,26 @@ from django.views.decorators.clickjacking import xframe_options_exempt
 from django.utils.translation import gettext as _
 
 from rest_framework import status
-from rest_framework.decorators import api_view, renderer_classes
+from rest_framework.decorators import api_view, renderer_classes, parser_classes
 from rest_framework.response import Response
 from rest_framework.request import Request
-from rest_framework.renderers import TemplateHTMLRenderer, JSONRenderer
+from rest_framework.renderers import (
+    TemplateHTMLRenderer,
+    JSONRenderer,
+    BrowsableAPIRenderer,
+)
+from rest_framework.parsers import MultiPartParser, FormParser, JSONParser
 from stellar_sdk.keypair import Keypair
 from stellar_sdk.exceptions import Ed25519PublicKeyInvalidError
 
 from polaris import settings
 from polaris.templates import Template
 from polaris.utils import (
+    getLogger,
     render_error_response,
     extract_sep9_fields,
     create_transaction_id,
-    memo_str,
+    make_memo,
 )
 from polaris.sep10.utils import validate_sep10_token
 from polaris.sep24.utils import (
@@ -54,6 +59,7 @@ logger = getLogger(__name__)
 @xframe_options_exempt
 @api_view(["POST"])
 @renderer_classes([TemplateHTMLRenderer])
+@parser_classes([MultiPartParser, FormParser, JSONParser])
 @check_authentication()
 def post_interactive_deposit(request: Request) -> Response:
     """
@@ -86,7 +92,7 @@ def post_interactive_deposit(request: Request) -> Response:
     callback = args_or_error["callback"]
     amount = args_or_error["amount"]
 
-    form = rdi.form_for_transaction(transaction, post_data=request.POST)
+    form = rdi.form_for_transaction(transaction, post_data=request.data)
     if not form:
         logger.error(
             "Initial form_for_transaction() call returned None in "
@@ -107,7 +113,7 @@ def post_interactive_deposit(request: Request) -> Response:
         )
 
     if not form.is_bound:
-        # The anchor must initialize the form with the request.POST data
+        # The anchor must initialize the form with the request data
         logger.error("form returned was not initialized with POST data, returning 500")
         return render_error_response(
             _("Unable to validate form submission."),
@@ -140,9 +146,10 @@ def post_interactive_deposit(request: Request) -> Response:
             invalidate_session(request)
             transaction.status = Transaction.STATUS.pending_user_transfer_start
             transaction.save()
-            url = reverse("more_info")
-            args = urlencode({"id": transaction.id, "callback": callback})
-            return redirect(f"{url}?{args}")
+            args = {"id": transaction.id, "initialLoad": "true"}
+            if callback:
+                args["callback"] = callback
+            return redirect(f"{reverse('more_info')}?{urlencode(args)}")
 
     else:
         content = (
@@ -206,11 +213,10 @@ def complete_interactive_deposit(request: Request) -> Response:
             _("ID passed is not a valid transaction ID"), content_type="text/html"
         )
     logger.info(f"Hands-off interactive flow complete for transaction {transaction_id}")
-    url, args = (
-        reverse("more_info"),
-        urlencode({"id": transaction_id, "callback": callback}),
-    )
-    return redirect(f"{url}?{args}")
+    args = {"id": transaction_id, "initialLoad": "true"}
+    if callback:
+        args["callback"] = callback
+    return redirect(f"{reverse('more_info')}?{urlencode(args)}")
 
 
 @xframe_options_exempt
@@ -243,6 +249,9 @@ def get_interactive_deposit(request: Request) -> Response:
     asset = args_or_error["asset"]
     callback = args_or_error["callback"]
     amount = args_or_error["amount"]
+    if args_or_error["on_change_callback"]:
+        transaction.on_change_callback = args_or_error["on_change_callback"]
+        transaction.save()
 
     url = rdi.interactive_url(request, transaction, asset, amount, callback)
     if url:  # The anchor uses a standalone interactive flow
@@ -306,7 +315,8 @@ def get_interactive_deposit(request: Request) -> Response:
 
 
 @api_view(["POST"])
-@renderer_classes([JSONRenderer])
+@renderer_classes([JSONRenderer, BrowsableAPIRenderer])
+@parser_classes([MultiPartParser, FormParser, JSONParser])
 @validate_sep10_token()
 def deposit(account: str, request: Request) -> Response:
     """
@@ -315,11 +325,11 @@ def deposit(account: str, request: Request) -> Response:
     Creates an `incomplete` deposit Transaction object in the database and
     returns the URL entry-point for the interactive flow.
     """
-    asset_code = request.POST.get("asset_code")
-    stellar_account = request.POST.get("account")
-    lang = request.POST.get("lang")
-    sep9_fields = extract_sep9_fields(request.POST)
-    claimable_balance_supported = request.POST.get("claimable_balance_supported")
+    asset_code = request.data.get("asset_code")
+    stellar_account = request.data.get("account")
+    lang = request.data.get("lang")
+    sep9_fields = extract_sep9_fields(request.data)
+    claimable_balance_supported = request.data.get("claimable_balance_supported")
     if not claimable_balance_supported:
         claimable_balance_supported = False
     elif isinstance(claimable_balance_supported, str):
@@ -349,16 +359,16 @@ def deposit(account: str, request: Request) -> Response:
 
     # Ensure memo won't cause stellar transaction to fail when submitted
     try:
-        memo = memo_str(request.POST.get("memo"), request.POST.get("memo_type"))
+        make_memo(request.data.get("memo"), request.data.get("memo_type"))
     except ValueError:
         return render_error_response(_("invalid 'memo' for 'memo_type'"))
 
     amount = None
-    if request.POST.get("amount"):
+    if request.data.get("amount"):
         try:
-            amount = Decimal(request.POST.get("amount"))
-        except DecimalException as e:
-            return render_error_response(_("Invalid 'amount'"))
+            amount = Decimal(request.data.get("amount"))
+        except DecimalException:
+            return render_error_response(_("invalid 'amount'"))
 
     # Verify that the asset code exists in our database, with deposit enabled.
     asset = Asset.objects.filter(code=asset_code).first()
@@ -373,7 +383,9 @@ def deposit(account: str, request: Request) -> Response:
         return render_error_response(_("invalid 'account'"))
 
     try:
-        rdi.save_sep9_fields(stellar_account, sep9_fields, lang)
+        rdi.save_sep9_fields(
+            stellar_account, sep9_fields, lang,
+        )
     except ValueError as e:
         # The anchor found a validation error in the sep-9 fields POSTed by
         # the wallet. The error string returned should be in the language
@@ -391,8 +403,11 @@ def deposit(account: str, request: Request) -> Response:
         to_address=account,
         protocol=Transaction.PROTOCOL.sep24,
         claimable_balance_supported=claimable_balance_supported,
-        memo=memo,
-        memo_type=request.POST.get("memo_type") or Transaction.MEMO_TYPES.hash,
+        memo=request.data.get("memo"),
+        memo_type=request.data.get("memo_type") or Transaction.MEMO_TYPES.hash,
+        more_info_url=request.build_absolute_uri(
+            f"{reverse('more_info')}?id={transaction_id}"
+        ),
     )
     logger.info(f"Created deposit transaction {transaction_id}")
 
