@@ -1,22 +1,28 @@
 from typing import Dict, Tuple
-from polaris.utils import getLogger
+from decimal import Decimal, DecimalException
 
 from django.utils.translation import gettext as _
-from rest_framework.decorators import api_view, renderer_classes
+from django.core.validators import URLValidator
+from django.core.exceptions import ValidationError
+from rest_framework.decorators import api_view, renderer_classes, parser_classes
 from rest_framework.request import Request
 from rest_framework.response import Response
-from rest_framework.renderers import JSONRenderer
+from rest_framework.renderers import JSONRenderer, BrowsableAPIRenderer
+from rest_framework.parsers import MultiPartParser, FormParser, JSONParser
 from rest_framework.exceptions import APIException
 from stellar_sdk.exceptions import MemoInvalidException
 
+from polaris import settings
 from polaris.models import Asset, Transaction
 from polaris.locale.utils import validate_language, activate_lang_for_request
 from polaris.utils import (
+    getLogger,
     render_error_response,
     create_transaction_id,
     extract_sep9_fields,
-    memo_str,
+    make_memo,
 )
+from polaris.shared.endpoints import SEP6_MORE_INFO_PATH
 from polaris.sep6.utils import validate_403_response
 from polaris.sep10.utils import validate_sep10_token
 from polaris.integrations import (
@@ -30,8 +36,9 @@ logger = getLogger(__name__)
 
 
 @api_view(["GET"])
-@renderer_classes([JSONRenderer])
-@validate_sep10_token("sep6")
+@renderer_classes([JSONRenderer, BrowsableAPIRenderer])
+@parser_classes([MultiPartParser, FormParser, JSONParser])
+@validate_sep10_token()
 def deposit(account: str, request: Request) -> Response:
     args = parse_request_args(request)
     if "error" in args:
@@ -49,6 +56,11 @@ def deposit(account: str, request: Request) -> Response:
         memo_type=args["memo_type"] or Transaction.MEMO_TYPES.text,
         to_address=account,
         protocol=Transaction.PROTOCOL.sep6,
+        more_info_url=request.build_absolute_uri(
+            f"{SEP6_MORE_INFO_PATH}?id={transaction_id}"
+        ),
+        claimable_balance_supported=args["claimable_balance_supported"],
+        on_change_callback=args["on_change_callback"],
     )
 
     try:
@@ -85,19 +97,21 @@ def validate_response(
     """
     Validate /deposit response returned from integration function
     """
-    account = args["account"]
-    asset = args["asset"]
     if "type" in integration_response:
-        return validate_403_response(account, integration_response, transaction), 403
+        return validate_403_response(integration_response, transaction), 403
 
+    asset = args["asset"]
+    if not (
+        "how" in integration_response and isinstance(integration_response["how"], str)
+    ):
+        logger.error("Invalid 'how' returned from process_sep6_request()")
+        raise ValueError()
     response = {
         "min_amount": round(asset.deposit_min_amount, asset.significant_decimals),
         "max_amount": round(asset.deposit_max_amount, asset.significant_decimals),
         "how": integration_response["how"],
+        "id": transaction.id,
     }
-    if not isinstance(response["how"], str):
-        logger.error("Invalid 'how' returned from process_sep6_request()")
-        raise ValueError()
 
     if calculate_fee == registered_fee_func:
         # Polaris user has not replaced default fee function, so fee_fixed
@@ -135,16 +149,60 @@ def parse_request_args(request: Request) -> Dict:
         return {"error": render_error_response(_("invalid 'memo_type'"))}
 
     try:
-        memo = memo_str(request.GET.get("memo"), memo_type)
+        make_memo(request.GET.get("memo"), memo_type)
     except (ValueError, MemoInvalidException):
         return {"error": render_error_response(_("invalid 'memo' for 'memo_type'"))}
 
+    claimable_balance_supported = request.GET.get(
+        "claimable_balance_supported", ""
+    ).lower()
+    if claimable_balance_supported not in ["", "true", "false"]:
+        return {
+            "error": render_error_response(
+                _("'claimable_balance_supported' value must be 'true' or 'false'")
+            )
+        }
+    else:
+        claimable_balance_supported = claimable_balance_supported == "true"
+
+    on_change_callback = request.GET.get("on_change_callback")
+    if on_change_callback and on_change_callback.lower() != "postmessage":
+        schemes = ["https"] if not settings.LOCAL_MODE else ["https", "http"]
+        try:
+            URLValidator(schemes=schemes)(on_change_callback)
+        except ValidationError:
+            return {"error": render_error_response(_("invalid callback URL provided"))}
+        if any(
+            domain in on_change_callback
+            for domain in settings.CALLBACK_REQUEST_DOMAIN_DENYLIST
+        ):
+            on_change_callback = None
+
+    amount = request.GET.get("amount")
+    if amount:
+        try:
+            amount = round(Decimal(amount), asset.significant_decimals)
+        except DecimalException:
+            return {"error": render_error_response(_("invalid 'amount'"))}
+        min_amount = round(asset.deposit_min_amount, asset.significant_decimals)
+        max_amount = round(asset.deposit_max_amount, asset.significant_decimals)
+        if not (min_amount <= amount <= max_amount):
+            return {
+                "error": render_error_response(
+                    _("'amount' must be within [%s, %s]") % (min_amount, min_amount)
+                )
+            }
+
     args = {
         "asset": asset,
         "memo_type": memo_type,
-        "memo": memo,
+        "memo": request.GET.get("memo"),
         "lang": lang,
         "type": request.GET.get("type"),
+        "claimable_balance_supported": claimable_balance_supported,
+        "on_change_callback": on_change_callback,
+        "country_code": request.GET.get("country_code"),
+        "amount": amount,
         **extract_sep9_fields(request.GET),
     }
 
